import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max, format, extent  } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { Dropdown } from './Dropdown';
import ReactDropdown from 'react-dropdown';

const width = 960;
const menuHeight = 60;
const height = 500 - menuHeight;
const margin = {top: 50, right:50, bottom:70, left: 100};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 50;
const tickOffset = 5;
const circleRadius = 7;

const attributes = [
  {value: "Month", label: "Month"},
  {value: "Zona", label: "Zona"},
  {value: "WasteKgs", label: "WasteKgs"}
  ];

const getLabel = value => {
	for( let i = 0; i < attributes.length; i++) {
		if(attributes[i].value == value){
    	return attributes[i].label;
    }
	}
}

const App = () => {

  const data = useData();

  const initialxAttribute = 'Month'
  const [xAttribute, setXAttribute] = useState(initialxAttribute);
  const xValue = d => d[xAttribute];
  const xAxisLabel = getLabel(xAttribute);
  
  const initialYAttribute = 'WasteKgs'
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute);
  
  if (!data) {
    return <pre>Loading...</pre>;
  }
    
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
	const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G','B')
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  

	console.log("X Scale Ticks:", xScale.ticks(5));
 	console.log("Y Scale Ticks:", yScale.domain());
  return (
    <>
      <div className="menus-container">
    <span className="dropdown-label">X: </span>
      <ReactDropdown 
        options={attributes} 
        value={xAttribute}
        onChange={({ value }) => setXAttribute(value)}
        />
    <span className="dropdown-label">Y: </span>
      <ReactDropdown 
        options={attributes} 
        value={yAttribute}
        onChange={({ value }) => setYAttribute(value)}
        />
      </div>
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom 
          xScale={xScale} 
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={tickOffset}
          />
        <text 
          className="axis-label" 
          x={innerWidth / 2} 
          y={innerHeight + xAxisLabelOffset} 
          textAnchor="middle">
          {xAxisLabel}
        </text>
        <AxisLeft 
          yScale={yScale} 
          innerWidth={innerWidth} 
          />
        <text 
          className="axis-label" 
          textAnchor="middle"
          transform={` translate(${-yAxisLabelOffset},${innerHeight / 2}),rotate(-90)`}
          >
          {yAxisLabel}
        </text>
        <Marks 
          data={data} 
          xScale={xScale} 
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={circleRadius}
          />
      </g>
    </svg>
      </>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);